"use strict";
this.haketilo_exports = this.haketilo_exports || {};
this.haketilo_exports["html/DOM_helpers.js"] = {};

(function() {
var globalThis = this.haketilo_this
{
/**
 * This file is part of Haketilo.
 *
 * Function: Operations on DOM elements.
 *
 * Copyright (C) 2021 Wojtek Kosior
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * As additional permission under GNU GPL version 3 section 7, you
 * may distribute forms of that code without the copy of the GNU
 * GPL normally required by section 4, provided you include this
 * license notice and, in case of non-source distribution, a URL
 * through which recipients can access the Corresponding Source.
 * If you modify file(s) with this exception, you may extend this
 * exception to your version of the file(s), but you are not
 * obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * As a special exception to the GPL, any HTML file which merely
 * makes function calls to this code, and for that purpose
 * includes it by reference shall be deemed a separate work for
 * copyright law purposes. If you modify this code, you may extend
 * this exception to your version of the code, but you are not
 * obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * I, Wojtek Kosior, thereby promise not to sue for violation of this file's
 * license. Although I request that you do not make use of this code in a
 * proprietary program, I am not going to enforce this in court.
 */

this.haketilo_exports["html/DOM_helpers.js"].by_id = (id => document.getElementById(id));

const known_templates = new Map();

function get_template(template_id)
{
    let template = known_templates.get(template_id) || null;
    if (template)
	return template;

    for (const template_node of document.getElementsByTagName("TEMPLATE")) {
	template = template_node.content.getElementById(template_id);
	if (template)
	    break;
    }

    known_templates.set(template_id, template);
    return template;
}
this.haketilo_exports["html/DOM_helpers.js"].get_template = (get_template);

function clone_template(template_id)
{
    const clone = get_template(template_id).cloneNode(true);
    const result_object = {};
    const to_process = [clone];

    while (to_process.length > 0) {
	const element = to_process.pop();
	let template_key = element.getAttribute("data-template") || element.id;

	if (template_key)
	    result_object[template_key] = element;

	element.removeAttribute("id");
	element.removeAttribute("data-template");

	for (const child of element.children)
	    to_process.push(child);
    }

    return result_object;
}
this.haketilo_exports["html/DOM_helpers.js"].clone_template = (clone_template);

function Showable(on_show_cb, on_hide_cb) {
    this.shown = false;

    /*
     * Wrap the requested callback into one that only executes it if showable is
     * not shown.
     */
    this.when_hidden = cb => {
	const wrapped_cb = (...args) => {
	    if (!this.shown)
		return cb(...args);
	}
	return wrapped_cb;
    }

    this.show = () => {
	if (this.shown)
	    return false;

	this.shown = true;

	try {
	    on_show_cb();
	} catch(e) {
	    console.error("Haketilo:", e);
	}

	return true;
    }

    this.hide = () => {
	if (!this.shown)
	    return false;

	this.shown = false;

	try {
	    on_hide_cb();
	} catch(e) {
	    console.error("Haketilo:", e);
	}

	return true;
    }
}
this.haketilo_exports["html/DOM_helpers.js"].Showable = (Showable);
}
}).call({
    haketilo_exports: this.haketilo_exports,
    haketilo_this:    this
});
