"use strict";
this.haketilo_exports = this.haketilo_exports || {};
this.haketilo_exports["html/default_blocking_policy.js"] = {};

(function() {
var globalThis = this.haketilo_this
{
/**
 * This file is part of Haketilo.
 *
 * Function: Logic for the dialog of default policy selection.
 *
 * Copyright (C) 2021 Wojtek Kosior
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * As additional permission under GNU GPL version 3 section 7, you
 * may distribute forms of that code without the copy of the GNU
 * GPL normally required by section 4, provided you include this
 * license notice and, in case of non-source distribution, a URL
 * through which recipients can access the Corresponding Source.
 * If you modify file(s) with this exception, you may extend this
 * exception to your version of the file(s), but you are not
 * obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * As a special exception to the GPL, any HTML file which merely
 * makes function calls to this code, and for that purpose
 * includes it by reference shall be deemed a separate work for
 * copyright law purposes. If you modify this code, you may extend
 * this exception to your version of the code, but you are not
 * obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * I, Wojtek Kosior, thereby promise not to sue for violation of this file's
 * license. Although I request that you do not make use of this code in a
 * proprietary program, I am not going to enforce this in court.
 */

const haketilodb = haketilo_exports["common/indexeddb.js"];

const by_id = haketilo_exports["html/DOM_helpers.js"].by_id;

/*
 * Used with `default_blocking_policy.html' to allow user to choose whether to
 * block scripts globally or not.
 */

const blocking_policy_span = by_id("blocking_policy_span");
const current_policy_span = by_id("current_policy_span");
const toggle_policy_but = by_id("toggle_policy_but");

let default_allow = false;

function update_policy(change)
{
    if (change)
	default_allow = (change.new_val || {}).value;
    current_policy_span.textContent = default_allow ? "allow" : "block";
}

async function track_default_allow()
{
    const set_val = ch => default_allow = (ch.new_val || {}).value;
    const [tracking, settings] = await haketilodb.track.setting(update_policy);
    for (const setting of settings) {
	if (setting.name === "default_allow")
	    default_allow = setting.value;
    }
    update_policy();
}

const toggle_policy =
      () => haketilodb.set_setting("default_allow", !default_allow);

async function init_default_policy_dialog()
{
    await track_default_allow();
    toggle_policy_but.addEventListener("click", toggle_policy);
}

init_default_policy_dialog();
}
}).call({
    haketilo_exports: this.haketilo_exports,
    haketilo_this:    this
});
