"use strict";
this.haketilo_exports = this.haketilo_exports || {};
this.haketilo_exports["html/file_preview.js"] = {};

(function() {
var globalThis = this.haketilo_this
{
/**
 * This file is part of Haketilo.
 *
 * Function: Haketilo's preview of a file kept in IndexedDB.
 *
 * Copyright (C) 2022 Wojtek Kosior
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * As additional permission under GNU GPL version 3 section 7, you
 * may distribute forms of that code without the copy of the GNU
 * GPL normally required by section 4, provided you include this
 * license notice and, in case of non-source distribution, a URL
 * through which recipients can access the Corresponding Source.
 * If you modify file(s) with this exception, you may extend this
 * exception to your version of the file(s), but you are not
 * obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * As a special exception to the GPL, any HTML file which merely
 * makes function calls to this code, and for that purpose
 * includes it by reference shall be deemed a separate work for
 * copyright law purposes. If you modify this code, you may extend
 * this exception to your version of the code, but you are not
 * obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * I, Wojtek Kosior, thereby promise not to sue for violation of this file's
 * license. Although I request that you do not make use of this code in a
 * proprietary program, I am not going to enforce this in court.
 */

const haketilodb = haketilo_exports["common/indexeddb.js"];

const by_id = haketilo_exports["html/DOM_helpers.js"].by_id;

const error_msg = by_id("error_msg"), info_msg = by_id("info_msg");

function error(msg) {
    info_msg.remove();
    error_msg.classList.remove("hide");
    error_msg.innerText = msg;
}

async function show_preview(hash_key) {
    const db = await haketilodb.get();
    const file = await haketilodb.idb_get(db.transaction("file"),
					  "file", hash_key);
    if (file === undefined) {
	error("Couldn't find file in Haketilo's internal database :(");
    } else {
	const blobby_opts = {type: "text/plain;charset=UTF-8"};
	const blobby = new Blob([file.contents], blobby_opts);
	location.replace(URL.createObjectURL(blobby));
    }
}

const match = /^[^#]*#(.*)$/.exec(document.URL);
if (!match) {
    error("Bad URL :(");
} else {
    const hash_key = match[1];
    show_preview(hash_key);
}
}
}).call({
    haketilo_exports: this.haketilo_exports,
    haketilo_this:    this
});
